require('datejs');

class DateUtils {
  /**
   * Returns a string with the format of HH:HH (DATE), based on the company's timeConfiguration
   *
   * @param company {any}
   * @param format {string}
   * @param date? {Date}
   * @return {string}
   */
  static getNowTimeString(company, format, date) {
    const parsedDate = date || new Date();

    const { timezone, hourFormat } = (company && company.timeConfiguration) || {
      timezone: null,
      hourFormat: null,
    };

    if (timezone != null) {
      let timezoneOffset = timezone && Number(timezone);
      timezoneOffset = (60 / 100) * timezoneOffset;

      const minutesToAdd = timezoneOffset + new Date().getTimezoneOffset();

      parsedDate.addMinutes(minutesToAdd);
    }

    return `${parsedDate.format(hourFormat === 12 ? '%r' : '%R')} (${parsedDate.format(format)}) `;
  }
}

module.exports = DateUtils;
